@@ -8,7 +8,7 @@ class RequestPathNotFound:
             'Content-Type': 'text/html; charset=utf-8'
         }
         code = 444
-        resp_data = f'Lyrebird cannot handle this request: {handler_context.flow["url"]}\n'
+        resp_data = f'Lyrebird cannot handle this request: {handler_context.flow.get("url")}\n'
 
         handler_context.flow['response']['headers'] = headers
         handler_context.flow['response']['code'] = code
